@@ -1,4 +1,4 @@
 """The analysis subpackage for PlasmaPy."""
 __all__ = []
 
-from plasmapy.analysis import fit_functions
+from plasmapy.analysis import fit_functions, swept_langmuir
