@@ -25,11 +25,21 @@ import numpy as np
 from astropy.constants import si as const
 from astropy.visualization import quantity_support
 from scipy.optimize import curve_fit
+from warnings import warn
 
 from plasmapy.particles import Particle
 from plasmapy.utils.decorators import validate_quantities
 
 
+def _langmuir_futurewarning() -> None:
+    warn(
+        "The plasmapy.diagnostics.langmuir module will be deprecated in favor of "
+        "the plasmapy.analysis.swept_langmuir sub-package and phased out over "
+        "2021.  The plasmapy.analysis package was released in v0.5.0.",
+        FutureWarning,
+    )
+
+
 def _fit_func_lin(x, x0, y0, c0):
     r"""Linear fitting function."""
 
@@ -72,6 +82,8 @@ class Characteristic:
 
     @validate_quantities(bias={"can_be_inf": False}, current={"can_be_inf": False})
     def __init__(self, bias: u.V, current: u.A):
+        _langmuir_futurewarning()
+
         self.bias = bias
         self.current = current
         self.get_unique_bias(True)
@@ -284,6 +296,8 @@ def swept_probe_analysis(
     for OML theory hold.
 
     """
+    _langmuir_futurewarning()
+
     # Instantiate gas using the Particle class
     gas = Particle(argument=gas_argument)
 
@@ -467,6 +481,8 @@ def get_plasma_potential(probe_characteristic, return_arg=False):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -517,6 +533,8 @@ def get_floating_potential(probe_characteristic, return_arg=False):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -554,6 +572,8 @@ def get_electron_saturation_current(probe_characteristic):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -589,6 +609,8 @@ def get_ion_saturation_current(probe_characteristic):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -653,6 +675,8 @@ def get_ion_density_LM(
 
     """
 
+    _langmuir_futurewarning()
+
     # Calculate the acoustic (Bohm) velocity
     c_s = np.sqrt(T_e / gas)
 
@@ -713,6 +737,8 @@ def get_electron_density_LM(
 
     """
 
+    _langmuir_futurewarning()
+
     # Calculate the thermal electron velocity
     v_th = np.sqrt(8 * T_e / (np.pi * const.m_e))
 
@@ -753,6 +779,8 @@ def extract_exponential_section(probe_characteristic, T_e=None, ion_current=None
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -807,6 +835,8 @@ def extract_ion_section(probe_characteristic):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -876,6 +906,8 @@ def get_electron_temperature(
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(exponential_section, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -1038,6 +1070,8 @@ def extrapolate_electron_current(
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -1126,6 +1160,8 @@ def reduce_bimaxwellian_temperature(T_e: u.eV, hot_fraction: float) -> u.eV:
 
     """
 
+    _langmuir_futurewarning()
+
     # Return the electron temperature itself if it is not bi-Maxwellian
     # in the first place.
     if hot_fraction is None or not np.array(T_e).size > 1:
@@ -1188,6 +1224,8 @@ def get_ion_density_OML(
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -1273,6 +1311,8 @@ def extrapolate_ion_current_OML(probe_characteristic, fit, visualize=False):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
@@ -1355,6 +1395,8 @@ def get_EEDF(probe_characteristic, visualize=False):
 
     """
 
+    _langmuir_futurewarning()
+
     if not isinstance(probe_characteristic, Characteristic):
         raise TypeError(
             f"For 'probe_characteristic' expected type "
