@@ -37,32 +37,32 @@ def Maxwellian_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"):
     Probability distribution function of velocity for a Maxwellian
     distribution in 1D.
 
-    Returns the probability density function at the velocity `v` in m/s
-    to find a particle `particle` in a plasma of temperature `T`
+    Returns the probability density function at the velocity ``v`` in m/s
+    to find a particle ``particle`` in a plasma of temperature ``T``
     following the Maxwellian distribution function.
 
     Parameters
     ----------
-    v: ~astropy.units.Quantity
+    v : `~astropy.units.Quantity`
         The velocity in units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature in kelvin.
 
-    particle: str, optional
+    particle : `str`, optional
         Representation of the particle species(e.g., ``'p'`` for protons,
-        ``'D+'`` for deuterium, or ``'He-4 +1'`` for :math:`He_4^{+1}`
-        (singly ionized helium-4)), which defaults to electrons.
+        ``'D+'`` for deuterium, or ``'He-4 +1'`` for singly ionized
+        helium-4), which defaults to electrons.
 
-    v_drift: ~astropy.units.Quantity, optional
+    v_drift : `~astropy.units.Quantity`, optional
         The drift velocity in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable velocity) in m/s. This is used for
-        optimization purposes to avoid re-calculating vTh, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -70,20 +70,20 @@ def Maxwellian_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"):
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in units of Velocity^-1, normalized so that
-        :math:`\int_{-\infty}^{+\infty} f(v) dv = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in units of velocity\ :sup:`-1`\ , normalized so that
+        :math:`\int_{-∞}^{+∞} f(v) dv = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         The parameter arguments are not Quantities and
         cannot be converted into Quantities.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters are not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -114,7 +114,7 @@ def Maxwellian_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"):
         # Catching case where drift velocities have default values, they
         # need to be assigned units
         v_drift = _v_drift_units(v_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -123,7 +123,7 @@ def Maxwellian_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"):
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = (
             parameters.thermal_speed(T * u.K, particle=particle, method="most_probable")
         ).si.value
@@ -155,32 +155,32 @@ def Maxwellian_velocity_2D(
 
     Parameters
     ----------
-    vx: ~astropy.units.Quantity
+    vx : `~astropy.units.Quantity`
         The velocity in x-direction units convertible to m/s.
 
-    vy: ~astropy.units.Quantity
+    vy : `~astropy.units.Quantity`
         The velocity in y-direction units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    particle: str, optional
-        Representation of the particle species (e.g., ``'p'`` for protons,
+    particle : `str`, optional
+        Representation of the particle species [e.g., ``'p'`` for protons,
         ``'D+'`` for deuterium, or ``'He-4 +1'`` for :math:`He_4^{+1}`
-        (singly ionized helium-4)), which defaults to electrons.
+        (singly ionized helium-4)], which defaults to electrons.
 
-    vx_drift: ~astropy.units.Quantity, optional
-        The drift velocity in x-direction units convertible to m/s.
+    vx_drift : `~astropy.units.Quantity`, optional
+        The drift velocity in x-direction in units convertible to m/s.
 
-    vy_drift: ~astropy.units.Quantity, optional
-        The drift velocity in y-direction units convertible to m/s.
+    vy_drift : `~astropy.units.Quantity`, optional
+        The drift velocity in y-direction in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
-        optimization purposes to avoid re-calculating `vTh`, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -188,9 +188,9 @@ def Maxwellian_velocity_2D(
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in Velocity^-1, normalized so that
-        :math:`\iiint_{0}^{\infty} f(\vec{v}) d\vec{v} = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in Velocity\ :sup:`-1`\ , normalized so that
+        :math:`\iiint_{0}^∞ f(\vec{v}) d\vec{v} = 1`.
 
     Raises
     ------
@@ -218,7 +218,7 @@ def Maxwellian_velocity_2D(
 
     where :math:`v_{Th} = \sqrt{2 k_B T / m}` is the thermal speed.
 
-    See also
+    See Also
     --------
     Maxwellian_1D
 
@@ -245,7 +245,7 @@ def Maxwellian_velocity_2D(
         # need to be assigned units
         vx_drift = _v_drift_units(vx_drift)
         vy_drift = _v_drift_units(vy_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -254,7 +254,7 @@ def Maxwellian_velocity_2D(
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = parameters.thermal_speed(
             T * u.K, particle=particle, method="most_probable"
         ).si.value
@@ -289,44 +289,44 @@ def Maxwellian_velocity_3D(
     distribution in 3D.
 
     Return the probability density function for finding a particle with
-    velocity components `vx`, `vy`, and `vz` in m/s in an equilibrium
-    plasma of temperature `T` which follows the 3D Maxwellian distribution
+    velocity components ``vx``, ``vy``, and ``vz`` in m/s in an equilibrium
+    plasma of temperature ``T`` which follows the 3D Maxwellian distribution
     function. This function assumes Cartesian coordinates.
 
     Parameters
     ----------
-    vx: ~astropy.units.Quantity
-        The velocity in x-direction units convertible to m/s.
+    vx : `~astropy.units.Quantity`
+        The velocity in x-direction in units convertible to m/s.
 
-    vy: ~astropy.units.Quantity
+    vy : `~astropy.units.Quantity`
         The velocity in y-direction units convertible to m/s.
 
-    vz: ~astropy.units.Quantity
+    vz : `~astropy.units.Quantity`
         The velocity in z-direction units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    particle: str, optional
+    particle : `str`, optional
         Representation of the particle species (e.g., ``'p'`` for protons,
-        ``'D+'`` for deuterium, or ``'He-4 +1'`` for :math:`He_4^{+1}`
-        (singly ionized helium-4)), which defaults to electrons.
+        ``'D+'`` for deuterium, or ``'He-4 +1'`` for
+        singly ionized helium-4), which defaults to electrons.
 
-    vx_drift: ~astropy.units.Quantity, optional
+    vx_drift : `~astropy.units.Quantity`, optional
         The drift velocity in x-direction units convertible to m/s.
 
-    vy_drift: ~astropy.units.Quantity, optional
+    vy_drift : `~astropy.units.Quantity`, optional
         The drift velocity in y-direction units convertible to m/s.
 
-    vz_drift: ~astropy.units.Quantity, optional
+    vz_drift : `~astropy.units.Quantity`, optional
         The drift velocity in z-direction units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
-        optimization purposes to avoid re-calculating `vTh`, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -334,20 +334,20 @@ def Maxwellian_velocity_3D(
 
     Returns
     -------
-    f : ~astropy.units.Quantity
+    f : `~astropy.units.Quantity`
         Probability density in Velocity^-1, normalized so that
-        :math:`\iiint_{0}^{\infty} f(\vec{v}) d\vec{v} = 1`.
+        :math:`\iiint_{0}^∞ f(\vec{v}) d\vec{v} = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         A parameter argument is not a `~astropy.units.Quantity` and
         cannot be converted into a `~astropy.units.Quantity`.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -364,7 +364,7 @@ def Maxwellian_velocity_3D(
 
     where :math:`v_{Th} = \sqrt{2 k_B T / m}` is the thermal speed.
 
-    See also
+    See Also
     --------
     Maxwellian_1D
 
@@ -395,7 +395,7 @@ def Maxwellian_velocity_3D(
         vx_drift = _v_drift_units(vx_drift)
         vy_drift = _v_drift_units(vy_drift)
         vz_drift = _v_drift_units(vz_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -404,7 +404,7 @@ def Maxwellian_velocity_3D(
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = parameters.thermal_speed(
             T * u.K, particle=particle, method="most_probable"
         ).si.value
@@ -428,31 +428,31 @@ def Maxwellian_speed_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
     in 1D.
 
     Return the probability density function for finding a particle with
-    speed `v` in m/s in an equilibrium plasma of temperature `T` which
+    speed ``v`` in m/s in an equilibrium plasma of temperature ``T`` which
     follows the Maxwellian distribution function.
 
     Parameters
     ----------
-    v: ~astropy.units.Quantity
+    v : `~astropy.units.Quantity`
         The speed in units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    particle: str, optional
-        Representation of the particle species(e.g., `'p'` for protons, `'D+'`
-        for deuterium, or `'He-4 +1'` for :math:`He_4^{+1}`
-        (singly ionized helium-4)), which defaults to electrons.
+    particle : `str`, optional
+        Representation of the particle species [e.g., ``'p'`` for protons, ``'D+'``
+        for deuterium, or ``'He-4 +1'`` for :math:`He_4^{+1}`
+        (singly ionized helium-4)], which defaults to electrons.
 
-    v_drift: ~astropy.units.Quantity
+    v_drift : `~astropy.units.Quantity`
         The drift speed in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
-        optimization purposes to avoid re-calculating vTh, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -460,32 +460,32 @@ def Maxwellian_speed_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in speed^-1, normalized so that
-        :math:`\int_{0}^{\infty} f(v) dv = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in speed\ :sup:`-1`\ , normalized so that
+        :math:`\int_{0}^∞ f(v) dv = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         The parameter arguments are not Quantities and
         cannot be converted into Quantities.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
     Notes
     -----
     In one dimension, the Maxwellian speed distribution function describing
-    the distribution of particles with speed v in a plasma with temperature T
-    is given by:
+    the distribution of particles with speed :math:`v` in a plasma with
+    temperature :math:`T` is given by:
 
     .. math::
 
-       f(v) = 2 \frac{1}{(\pi v_{Th}^2)^{1/2}} \exp(-(v - V_{drift})^2 / v_{Th}^2 )
+       f(v) = 2 \frac{1}{(π v_{Th}^2)^{1/2}} \exp(-(v - V_{drift})^2 / v_{Th}^2 )
 
     where :math:`v_{Th} = \sqrt{2 k_B T / m}` is the thermal speed.
 
@@ -504,7 +504,7 @@ def Maxwellian_speed_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
         # Catching case where drift velocities have default values, they
         # need to be assigned units
         v_drift = _v_drift_units(v_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -513,7 +513,7 @@ def Maxwellian_speed_1D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = (
             parameters.thermal_speed(T * u.K, particle=particle, method="most_probable")
         ).si.value
@@ -537,32 +537,32 @@ def Maxwellian_speed_2D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
     in 2D.
 
     Return the probability density function of finding a particle with speed components
-    `vx` and `vy` in m/s in an equilibrium plasma of temperature
-    `T` which follows the 2D Maxwellian distribution function. This
+    ``vx`` and ``vy`` in m/s in an equilibrium plasma of temperature
+    ``T`` which follows the 2D Maxwellian distribution function. This
     function assumes Cartesian coordinates.
 
     Parameters
     ----------
-    v: ~astropy.units.Quantity
+    v: `~astropy.units.Quantity`
         The speed in units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T: `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    particle: str, optional
-        Representation of the particle species(e.g., `'p'` for protons, `'D+'`
-        for deuterium, or `'He-4 +1'` for :math:`He_4^{+1}`
-        (singly ionized helium-4)), which defaults to electrons.
+    particle: `str`, optional
+        Representation of the particle species(e.g., ``'p'`` for protons, ``'D+'``
+        for deuterium, or ``'He-4 +1'`` for singly ionized helium-4),
+        which defaults to electrons.
 
-    v_drift: ~astropy.units.Quantity
+    v_drift: `~astropy.units.Quantity`
         The drift speed in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh: `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
-        optimization purposes to avoid re-calculating vTh, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units: `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -570,20 +570,20 @@ def Maxwellian_speed_2D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in speed^-1, normalized so that:
-        :math:`\iiint_{0}^{\infty} f(\vec{v}) d\vec{v} = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in \ :sup:`-1`\ , normalized so that:
+        :math:`\iiint_{0}^∞ f(\vec{v}) d\vec{v} = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         A parameter argument is not a `~astropy.units.Quantity` and
         cannot be converted into a `~astropy.units.Quantity`.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -595,11 +595,11 @@ def Maxwellian_speed_2D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
 
     .. math::
 
-       f = 2 \pi v (\pi v_{Th}^2)^{-1} \exp(-v^2 / v_{Th}^2)
+       f = 2 π v (π v_{Th}^2)^{-1} \exp(-v^2 / v_{Th}^2)
 
     where :math:`v_{Th} = \sqrt{2 k_B T / m}` is the thermal speed.
 
-    See also
+    See Also
     --------
     Maxwellian_speed_1D
 
@@ -620,7 +620,7 @@ def Maxwellian_speed_2D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
         # Catching case where drift velocity has default value, and
         # needs to be assigned units
         v_drift = _v_drift_units(v_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -629,7 +629,7 @@ def Maxwellian_speed_2D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = (
             parameters.thermal_speed(T * u.K, particle=particle, method="most_probable")
         ).si.value
@@ -654,32 +654,32 @@ def Maxwellian_speed_3D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
     distribution in 3D.
 
     Return the probability density function for finding a particle with
-    speed components `vx`, `vy`, and `vz` in m/s in an equilibrium
-    plasma of temperature `T` which follows the 3D Maxwellian
+    speed components ``vx``, ``vy``, and ``vz`` in m/s in an equilibrium
+    plasma of temperature ``T`` which follows the 3D Maxwellian
     distribution function. This function assumes Cartesian coordinates.
 
     Parameters
     ----------
-    v: ~astropy.units.Quantity
+    v : `~astropy.units.Quantity`
         The speed in units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    particle: str, optional
+    particle : `str`, optional
         Representation of the particle species(e.g., `'p'` for protons, `'D+'`
         for deuterium, or `'He-4 +1'` for :math:`He_4^{+1}`
         (singly ionized helium-4)), which defaults to electrons.
 
-    v_drift: ~astropy.units.Quantity
+    v_drift : `~astropy.units.Quantity`
         The drift speed in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
         optimization purposes to avoid re-calculating vTh, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -687,20 +687,20 @@ def Maxwellian_speed_3D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in speed^-1, normalized so that:
-        :math:`\iiint_{0}^{\infty} f(\vec{v}) d\vec{v} = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in speed\ :sup:`-1`\ , normalized so that:
+        :math:`\iiint_0^∞ f(\vec{v}) d\vec{v} = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         A parameter argument is not a `~astropy.units.Quantity` and
         cannot be converted into a `~astropy.units.Quantity`.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -712,11 +712,11 @@ def Maxwellian_speed_3D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
 
     .. math::
 
-       f = 4 \pi v^{2} (\pi v_{Th}^2)^{-3/2} \exp(-v^{2} / v_{Th}^2)
+       f = 4 π v^{2} (π v_{Th}^2)^{-3/2} \exp(-v^{2} / v_{Th}^2)
 
     where :math:`v_{Th} = \sqrt{2 k_B T / m}` is the thermal speed.
 
-    See also
+    See Also
     --------
     Maxwellian_speed_1D
 
@@ -737,7 +737,7 @@ def Maxwellian_speed_3D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
         # Catching case where drift velocity has default value, and
         # needs to be assigned units
         v_drift = _v_drift_units(v_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -746,7 +746,7 @@ def Maxwellian_speed_3D(v, T, particle="e", v_drift=0, vTh=np.nan, units="units"
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = (
             parameters.thermal_speed(T * u.K, particle=particle, method="most_probable")
         ).si.value
@@ -775,53 +775,53 @@ def kappa_velocity_1D(v, T, kappa, particle="e", v_drift=0, vTh=np.nan, units="u
 
     Parameters
     ----------
-    v: ~astropy.units.Quantity
+    v : `~astropy.units.Quantity`
         The velocity in units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature in kelvin.
 
-    kappa: ~astropy.units.Quantity
+    kappa : `~astropy.units.Quantity`
         The kappa parameter is a dimensionless number which sets the slope
         of the energy spectrum of suprathermal particles forming the tail
         of the Kappa velocity distribution function. Kappa must be greater
         than :math:`3/2`.
 
-    particle: str, optional
+    particle : `str`, optional
         Representation of the particle species(e.g., `'p` for protons, `'D+'`
         for deuterium, or `'He-4 +1'` for :math:`He_4^{+1}`
         (singly ionized helium-4)), which defaults to electrons.
 
-    v_drift: ~astropy.units.Quantity, optional
+    v_drift : `~astropy.units.Quantity`, optional
         The drift velocity in units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
         optimization purposes to avoid re-calculating `vTh`, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
-        equal to "units") or to run as unitless (when equal to "unitless").
-        The unitless version is substantially faster for intensive
-        computations.
+        equal to ``"units"``) or to run as unitless (when equal to
+        ``"unitless"``). The unitless version is substantially faster for
+        intensive computations.
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in Velocity^-1, normalized so that
-        :math:`\int_{-\infty}^{+\infty} f(v) dv = 1`.
+    f : `~astropy.units.Quantity`
+        Probability density in celocity\ :sup:`-1`\ , normalized so that
+        :math:`\int_{-∞}^{+∞} f(v) dv = 1`.
 
     Raises
     ------
-    TypeError
+    `TypeError`
         A parameter argument is not a `~astropy.units.Quantity` and
         cannot be converted into a `~astropy.units.Quantity`.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -829,21 +829,21 @@ def kappa_velocity_1D(v, T, kappa, particle="e", v_drift=0, vTh=np.nan, units="u
     -----
     In one dimension, the Kappa velocity distribution function describing
     the distribution of particles with speed :math:`v` in a plasma with
-    temperature :math:`T` and suprathermal parameter :math:`\kappa` is
+    temperature :math:`T` and suprathermal parameter :math:`κ` is
     given by:
 
     .. math::
 
-       f = A_\kappa \left(1 + \frac{(\vec{v} -
-       \vec{V_{drift}})^2}{\kappa v_{Th},\kappa^2}\right)^{-\kappa}
+       f = A_κ \left(1 + \frac{(\vec{v} -
+       \vec{V_{drift}})^2}{κ v_{Th},κ^2}\right)^{-κ}
 
-    where :math:`v_{Th},\kappa` is the kappa thermal speed
-    and :math:`A_\kappa = \frac{1}{\sqrt{\pi} \kappa^{3/2} v_{Th},\kappa^2
-    \frac{\Gamma(\kappa + 1)}{\Gamma(\kappa - 1/2)}}`
+    where :math:`v_{Th},κ` is the kappa thermal speed
+    and :math:`A_κ = \frac{1}{\sqrt{π} κ^{3/2} v_{Th},κ^2
+    \frac{Γ(κ + 1)}{Γ(κ - 1/2)}}`
     is the normalization constant.
 
-    As :math:`\kappa` approaches infinity, the kappa distribution function
-    converges to the Maxwellian distribution function.
+    As :math:`κ → ∞`, the kappa distribution function converges to the
+    Maxwellian distribution function.
 
     Examples
     --------
@@ -859,7 +859,7 @@ def kappa_velocity_1D(v, T, kappa, particle="e", v_drift=0, vTh=np.nan, units="u
     """
     # must have kappa > 3/2 for distribution function to be valid
     if kappa <= 3 / 2:
-        raise ValueError(f"Must have kappa > 3/2, instead of {kappa}.")
+        raise ValueError(f"Must have κ > 3/2, instead of {kappa}.")
     if units == "units":
         # unit checks and conversions
         # checking velocity units
@@ -871,7 +871,7 @@ def kappa_velocity_1D(v, T, kappa, particle="e", v_drift=0, vTh=np.nan, units="u
                 v_drift = v_drift * u.m / u.s
         # checking units of drift velocities
         v_drift = v_drift.to(u.m / u.s)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -880,7 +880,7 @@ def kappa_velocity_1D(v, T, kappa, particle="e", v_drift=0, vTh=np.nan, units="u
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = (
             parameters.kappa_thermal_speed(T * u.K, kappa, particle=particle)
         ).si.value
@@ -914,51 +914,51 @@ def kappa_velocity_3D(
 ):
     r"""
     Return the probability density function for finding a particle with
-    velocity components `v_x`, `v_y`, and `v_z`in m/s in a suprathermal
-    plasma of temperature `T` and parameter 'kappa' which follows the
+    velocity components ``v_x``, ``v_y``, and ``v_z``in m/s in a suprathermal
+    plasma of temperature ``T`` and parameter ``kappa`` which follows the
     3D Kappa distribution function. This function assumes Cartesian
     coordinates.
 
     Parameters
     ----------
-    vx: ~astropy.units.Quantity
+    vx : `~astropy.units.Quantity`
         The velocity in x-direction units convertible to m/s.
 
-    vy: ~astropy.units.Quantity
+    vy : `~astropy.units.Quantity`
         The velocity in y-direction units convertible to m/s.
 
-    vz: ~astropy.units.Quantity
+    vz : `~astropy.units.Quantity`
         The velocity in z-direction units convertible to m/s.
 
-    T: ~astropy.units.Quantity
-        The temperature, preferably in Kelvin.
+    T : `~astropy.units.Quantity`
+        The temperature, preferably in kelvin.
 
-    kappa: ~astropy.units.Quantity
+    kappa : `~astropy.units.Quantity`
         The kappa parameter is a dimensionless number which sets the slope
         of the energy spectrum of suprathermal particles forming the tail
-        of the Kappa velocity distribution function. Kappa must be greater
+        of the Kappa velocity distribution function. ``kappa`` must be greater
         than :math:`3/2`.
 
-    particle: str, optional
+    particle : `str`, optional
         Representation of the particle species(e.g., 'p' for protons, 'D+'
         for deuterium, or 'He-4 +1' for :math:`He_4^{+1}` : singly ionized
         helium-4)), which defaults to electrons.
 
-    vx_drift: ~astropy.units.Quantity, optional
+    vx_drift : `~astropy.units.Quantity`, optional
         The drift velocity in x-direction units convertible to m/s.
 
-    vy_drift: ~astropy.units.Quantity, optional
+    vy_drift : `~astropy.units.Quantity`, optional
         The drift velocity in y-direction units convertible to m/s.
 
-    vz_drift: ~astropy.units.Quantity, optional
+    vz_drift : `~astropy.units.Quantity`, optional
         The drift velocity in z-direction units convertible to m/s.
 
-    vTh: ~astropy.units.Quantity, optional
+    vTh : `~astropy.units.Quantity`, optional
         Thermal velocity (most probable) in m/s. This is used for
-        optimization purposes to avoid re-calculating `vTh`, for example
+        optimization purposes to avoid re-calculating ``vTh``, for example
         when integrating over velocity-space.
 
-    units: str, optional
+    units : `str`, optional
         Selects whether to run function with units and unit checks (when
         equal to "units") or to run as unitless (when equal to "unitless").
         The unitless version is substantially faster for intensive
@@ -966,20 +966,20 @@ def kappa_velocity_3D(
 
     Returns
     -------
-    f : ~astropy.units.Quantity
-        Probability density in Velocity^-1, normalized so that:
-        :math:`\iiint_{0}^{\infty} f(\vec{v}) d\vec{v} = 1`
+    f : `~astropy.units.Quantity`
+        Probability density in units of inverse velocity, normalized so that:
+        :math:`\iiint_{0}^∞ f(\vec{v}) d\vec{v} = 1`
 
     Raises
     ------
-    TypeError
-        The parameter arguments are not Quantities and
-        cannot be converted into Quantities.
+    `TypeError`
+        If any of the parameters is not a `~astropy.units.Quantity` and
+        cannot be converted into one.
 
-    ~astropy.units.UnitConversionError
+    `~astropy.units.UnitConversionError`
         If the parameters is not in appropriate units.
 
-    ValueError
+    `ValueError`
         If the temperature is negative, or the particle mass or charge state
         cannot be found.
 
@@ -987,22 +987,22 @@ def kappa_velocity_3D(
     -----
     In three dimensions, the Kappa velocity distribution function describing
     the distribution of particles with speed :math:`v` in a plasma with
-    temperature :math:`T` and suprathermal parameter :math:`\kappa` is given by:
+    temperature :math:`T` and suprathermal parameter :math:`κ` is given by:
 
     .. math::
 
-       f = A_\kappa \left(1 + \frac{(\vec{v} -
-       \vec{V_{drift}})^2}{\kappa v_{Th},\kappa^2}\right)^{-(\kappa + 1)}
+       f = A_κ \left(1 + \frac{(\vec{v} -
+       \vec{V_{drift}})^2}{κ v_{Th},κ^2}\right)^{-(κ + 1)}
 
-    where :math:`v_{Th},\kappa` is the kappa thermal speed
-    and :math:`A_\kappa = \frac{1}{2 \pi (\kappa v_{Th},\kappa^2)^{3/2}}
-    \frac{\Gamma(\kappa + 1)}{\Gamma(\kappa - 1/2) \Gamma(3/2)}` is the
+    where :math:`v_{Th},κ` is the kappa thermal speed
+    and :math:`A_κ = \frac{1}{2 π (κ v_{Th},κ^2)^{3/2}}
+    \frac{Γ(κ + 1)}{Γ(κ - 1/2) Γ(3/2)}` is the
     normalization constant.
 
-    As :math:`\kappa` approaches infinity, the kappa distribution function
-    converges to the Maxwellian distribution function.
+    As :math:`κ → ∞`, the kappa distribution function converges to the
+    Maxwellian distribution function.
 
-    See also
+    See Also
     --------
     kappa_velocity_1D
     kappa_thermal_speed
@@ -1036,7 +1036,7 @@ def kappa_velocity_3D(
         vx_drift = _v_drift_units(vx_drift)
         vy_drift = _v_drift_units(vy_drift)
         vz_drift = _v_drift_units(vz_drift)
-        # convert temperature to Kelvins
+        # convert temperature to kelvin
         T = T.to(u.K, equivalencies=u.temperature_energy())
         if np.isnan(vTh):
             # get thermal velocity and thermal velocity squared
@@ -1045,7 +1045,7 @@ def kappa_velocity_3D(
             # check units of thermal velocity
             vTh = vTh.to(u.m / u.s)
     elif np.isnan(vTh) and units == "unitless":
-        # assuming unitless temperature is in Kelvins
+        # assuming unitless temperature is in kelvin
         vTh = parameters.kappa_thermal_speed(T * u.K, kappa, particle=particle).si.value
     # getting square of thermal velocity
     vThSq = vTh ** 2
