@@ -1,3 +1,4 @@
-from . import sources
+from plasmapy.plasma import exceptions, sources
+
 from .plasma_base import BasePlasma, GenericPlasma
 from .plasma_factory import Plasma
