@@ -1,7 +1,4 @@
-"""
-Collection of `Exceptions` and `Warnings` for functionality defined in
-`plasmapy.plasma`.
-"""
+"""Exceptions and warnings for functionality defined in `plasmapy.plasma`."""
 __all__ = ["DataStandardError"]
 
 from plasmapy.utils import PlasmaPyError
