@@ -10,20 +10,18 @@ __all__ = [
     "PlasmaPyWarning",
     "RelativityError",
     "RelativityWarning",
-    "call_string",
     "decorators",
     "exceptions",
     "roman",
 ]
 
 from plasmapy.utils import (
+    code_repr,
     datatype_factory_base,
     decorators,
-    error_messages,
     exceptions,
     roman,
 )
-from plasmapy.utils.error_messages import call_string
 from plasmapy.utils.exceptions import (
     CouplingWarning,
     PhysicsError,
@@ -37,6 +35,6 @@ from plasmapy.utils.exceptions import (
 try:
     from plasmapy.utils import pytest_helpers
 except ModuleNotFoundError:
-    # pytest is not a hard dependency, so only import pytest_helpers is pytest
+    # pytest is not a hard dependency, so only import pytest_helpers if pytest
     # is installed
     pass
